# htpyp
A templating engine for python

A easy to use, fast templating tool for full stack python applications.
Documentation for this tool will be coming soon, however in the mean time you can use the example in main.py
